--[[

The options panel for the Plugin Manager.

]]--

_G.OptionsPanel = class(Turbine.UI.Control);

function OptionsPanel:Constructor()
	Turbine.UI.Control.Constructor(self);

	self:SetWidth(260);
	self:SetHeight(260);

	-- add checkbox to lock the position of the toggle icon
   self.lockIcon = Turbine.UI.Lotro.CheckBox();
	self.lockIcon:SetParent(self);
	self.lockIcon:SetSize(250, 20);
	self.lockIcon:SetPosition(10, 20);
	self.lockIcon:SetCheckAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
	self.lockIcon:SetChecked(settings.iconLocked);
   self.lockIcon:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
   self.lockIcon:SetForeColor(Turbine.UI.Color(245/255, 222/255, 147/255));
	self.lockIcon:SetMultiline(false);
	self.lockIcon:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
	self.lockIcon:SetText(" "..L.LockIcon);
	self.lockIcon.Icon = Turbine.UI.Control();
	self.lockIcon.Icon:SetParent(self.lockIcon);
	self.lockIcon.Icon:SetSize(32, 16);
	self.lockIcon.Icon:SetPosition(0, 2);
	self.lockIcon.Icon:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	self.lockIcon.Icon:SetMouseVisible(false);
	self.lockIcon.CheckedChanged = function(sender, args)
		settings.iconLocked = self.lockIcon:IsChecked();
		_G.iconPosLocked = self.lockIcon:IsChecked();

		SaveSettings();
	end

   self.currentSortLabel = Turbine.UI.Label();
	self.currentSortLabel:SetParent(self);
	self.currentSortLabel:SetSize(220, 20);
	self.currentSortLabel:SetPosition(10, 70);
   self.currentSortLabel:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
   self.currentSortLabel:SetForeColor(Turbine.UI.Color(245/255, 222/255, 147/255));
	self.currentSortLabel:SetMultiline(false);
	self.currentSortLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
	self.currentSortLabel:SetText(L.CurrentSort);

   self.currentSortSettings = Turbine.UI.Label();
	self.currentSortSettings:SetParent(self);
	self.currentSortSettings:SetSize(210, 30);
	self.currentSortSettings:SetPosition(20, 90);
   self.currentSortSettings:SetFont(Turbine.UI.Lotro.Font.Verdana12);
   self.currentSortSettings:SetForeColor(Turbine.UI.Color(1, 1, 1));
	self.currentSortSettings:SetMultiline(true);
	self.currentSortSettings:SetTextAlignment(Turbine.UI.ContentAlignment.TopLeft);
	self:SetCurrentSortText();

	-- button to load currently-configured sort and save as default
	self.saveCurrentSort = Turbine.UI.Lotro.Button();
	self.saveCurrentSort:SetParent(self);
	self.saveCurrentSort:SetSize(200, 20);
	self.saveCurrentSort:SetPosition(10, 120);
	self.saveCurrentSort:SetText(L.SaveAsDefault);
	self.saveCurrentSort.Click = function(sender, args)
		settings.defaultAllChars = showAllCharacters;

		if (sortByKillTime) then
			settings.defaultSort = "KillTime";
			settings.defaultSortOrd = "";
		else
			settings.defaultSort = currentSort;
			settings.defaultSortOrd = currentSortOrder;
		end

		SaveSettings();
	end

   self.serverNameLabel = Turbine.UI.Label();
	self.serverNameLabel:SetParent(self);
	self.serverNameLabel:SetSize(140, 20);
	self.serverNameLabel:SetPosition(10, 170);
   self.serverNameLabel:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
   self.serverNameLabel:SetForeColor(Turbine.UI.Color(245/255, 222/255, 147/255));
	self.serverNameLabel:SetMultiline(false);
	self.serverNameLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
	self.serverNameLabel:SetText(L.CurrentServerID);

	self.serverName = Turbine.UI.Lotro.TextBox();
	self.serverName:SetParent(self);
	self.serverName:SetSize(140, 20);
	self.serverName:SetPosition(10, 190);
   self.serverName:SetFont(Turbine.UI.Lotro.Font.Verdana14);
	self.serverName:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	self.serverName:SetText(serverLabels[serverID]);

	-- button to load currently-configured sort and save as default
	self.saveServerName = Turbine.UI.Lotro.Button();
	self.saveServerName:SetParent(self);
	self.saveServerName:SetSize(140, 20);
	self.saveServerName:SetPosition(10, 210);
	self.saveServerName:SetText(L.Save);
	self.saveServerName.Click = function(sender, args)
		self.serverName:SetText(string.gsub(self.serverName:GetText(), "[%(%)%*\t\n]", ""));

		if (serverLabels[serverID] ~= self.serverName:GetText()) then
			local oldServerLabel = serverLabels[serverID];
			local nameOK = true;
	
			-- make sure label isn't already in use by another server
			for i = 1, #serverLabels do
				if (serverLabels[i] == self.serverName:GetText()) then
					self.nameInUse:SetVisible(true);
	
					nameOK = false;
	
					break;
				end
			end
			
			if (#killsTable > 0) then
				for i = 1, #killsTable do
					if (string.find(killsTable[i][5], "%("..string.gsub(self.serverName:GetText(), "([%%%.%[%]%+%-%?])", "%%%1").."%)$") ~= nil) then
						self.nameInUse:SetVisible(true);

						nameOK = false;
		
						break;
					end
				end
			end
	
			if (nameOK) then
				self.nameInUse:SetVisible(false);
	
				serverLabels[serverID] = self.serverName:GetText();
	
				player.uniqueName = player.name.."("..serverLabels[serverID]..")";
				
				SaveServers();
				
				SaveServerID();
				
				local tmpCharNames = {};
				
				for k, v in pairs(characterNames) do
					tmpCharNames[k] = v;
				end
				
				for k, v in pairs(tmpCharNames) do
					if (string.find(k, "%("..string.gsub(oldServerLabel, "([%%%.%[%]%+%-%?])", "%%%1").."%)$") ~= nil) then
						characterNames[k] = nil;
				
						characterNames[string.gsub(k, "%("..string.gsub(oldServerLabel, "([%%%.%[%]%+%-%?])", "%%%1").."%)$", "("..serverLabels[serverID]..")")] = string.gsub(v, "%("..string.gsub(oldServerLabel, "([%%%.%[%]%+%-%?])", "%%%1").."%)$", "("..serverLabels[serverID]..")"); 
					end
				end
				
				if (#killsTable > 0) then
					for i = 1, #killsTable do
						killsTable[i][5] = string.gsub(killsTable[i][5], "%("..string.gsub(oldServerLabel, "([%%%.%[%]%+%-%?])", "%%%1").."%)$", "("..serverLabels[serverID]..")"); 
					end
				
					RefreshKillsDisplay()
				end
				
				SaveData();
			end	
		end
	end

   self.nameInUse = Turbine.UI.Label();
	self.nameInUse:SetParent(self);
	self.nameInUse:SetSize(240, 30);
	self.nameInUse:SetPosition(10, 230);
   self.nameInUse:SetFont(Turbine.UI.Lotro.Font.Verdana12);
   self.nameInUse:SetForeColor(Turbine.UI.Color(1, 0, 0));
	self.nameInUse:SetMultiline(true);
	self.nameInUse:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleLeft);
	self.nameInUse:SetText(L.ServerIdInUse);
	self.nameInUse:SetVisible(false);
end

function OptionsPanel:SetCurrentSortText()
	local tmpCurrentSort = "";
	
	if (sortByKillTime) then
		tmpCurrentSort = L.KillTime.."\n";
	else
		if (currentSort == "Enemy") then
			tmpCurrentSort = L.MobName;
		elseif (currentSort == "Character") then
			tmpCurrentSort = L.CharacterName;
		elseif (currentSort == "Level") then
			tmpCurrentSort = L.LevelRange;
		else -- currentSort == "Kills"
			tmpCurrentSort = L.KillCount;
		end
	
		if (currentSortOrder == "DESC") then
			tmpCurrentSort = tmpCurrentSort..DescSortChar.."\n";
		else
			tmpCurrentSort = tmpCurrentSort..AscSortChar.."\n";
		end
	end
	
	if (showAllCharacters) then
		tmpCurrentSort = tmpCurrentSort..L.ShowAllCharacters;
	else
		tmpCurrentSort = tmpCurrentSort..L.ShowCurrentCharacter;
	end
	
	self.currentSortSettings:SetText(tmpCurrentSort);
end